/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'nl', {
	border: 'Framerand tonen',
	noUrl: 'Vul de IFrame URL in',
	scrolling: 'Scrollbalken inschakelen',
	title: 'IFrame-eigenschappen',
	toolbar: 'IFrame',
	tabindex: 'Remove from tabindex' // MISSING
} );
